@@ -203,7 +203,7 @@ sub descend
   my $selectmixed = "$throwclean-select.csv";
 
   my $remember;
-  if ( $direction eq "stars" ) { $remember = $winneritems[$countcase][0]; }
+  #if ( $direction eq "stars" ) { $remember = $winneritems[$countcase][0]; }
 
   sub cleanselect
   {   # IT CLEANS THE MIXED FILE AND SELECTS SOME COLUMNS, THEN COPIES THEM IN ANOTHER FILE
@@ -750,7 +750,7 @@ sub descend
     }
     else
     {
-      if ( $direction eq "stars" ) { $newtarget = $remember; }
+      #if ( $direction eq "stars" ) { $newtarget = $remember; }
       push ( @{ $winneritems[$countcase][$countblock] }, $newtarget ); say $tee "TAKEOPTIMA->\@winneritems " . dump(@winneritems);
       say $tee "#Leaving case " . ($countcase + 1) . ", block " . ($countblock + 1) . " and descending!\ ";
       Sim::OPT::callcase( { countcase => $countcase, countblock => $countblock,
